==> django-object-toolbar-admin-0.1.1.tar.gz: django-object-toolbar-admin-0.1.1/setup.py <==
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-object-toolbar-admin",
    version="0.1.1",
    description="Add toolbar in every item line in django's changelist view, and on top of django's changeform view.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    url="https://github.com/zencore-cn/zencore-issues",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django object toolbar admin"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_object_toolbar_admin_example", "django_object_toolbar_admin_example.migrations", "django_object_toolbar_admin_demo"]),
    py_modules=["django_object_toolbar_admin"],
    zip_safe=False,
    include_package_data=True,
)

==> django-object-toolbar-admin-0.1.2.tar.gz: django-object-toolbar-admin-0.1.2/setup.py <==
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-object-toolbar-admin",
    version="0.1.2",
    description="Add toolbar in every item line in django's changelist view, and on top of django's changeform view.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Long Zheng",
    author_email="longzheng@zencore.cn",
    maintainer="Long Zheng",
    maintainer_email="longzheng@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django object toolbar admin"],
    install_requires=requires,
    packages=find_packages(
        ".",
        exclude=[
            "django_object_toolbar_admin_example",
            "django_object_toolbar_admin_example.migrations",
            "django_object_toolbar_admin_demo",
        ],
    ),
    py_modules=["django_object_toolbar_admin"],
    zip_safe=False,
    include_package_data=True,
)
